# TwoFourSeven
Python Package to scrape recruiting data from 247Sports website

Able to scrape transfer portal page as well.

## Classes:
<strong>Recruit</strong> <br>
  getClass(team, year) - Returns df of the recruiting class of a given team from the given year <br>
  getAllTime(team) - Returns df of top recruits for a team for recent history. <br>
<br>
<strong>TransferPortal</strong> <br>
  getData(year) - Returns df of everyone who entered the transferportal for a given year <br>
  
